@@ -1,12 +1,12 @@
 __version__ = "0.1.2"
 __name__ = "ospark"
 
-import ospark
+
 from ospark.nn.component.weight import Weight, WeightOperator
-from ospark.nn.component import weight
-from ospark.nn.component import activation
+from ospark.nn.component.basic_module import ModelObject
+from ospark.nn.layers import Layer, normalization, activation
 from ospark.utility import weight_initializer
-from ospark.nn.layers import Layer, normalization
+from ospark.nn.component import weight
+from ospark.nn.model import Model
 from ospark.nn.block import Block
-from ospark.nn.cell import Cell
-from ospark.nn.model import Model
\ No newline at end of file
+from ospark.nn.cell import Cell
\ No newline at end of file
